@@ -4,6 +4,7 @@ import asyncio
 import logging
 
 from nwp500 import Device, DeviceStatus, NavienMqttClient
+from nwp500.unit_system import get_unit_system
 
 from .output_formatters import write_status_to_csv
 
@@ -30,15 +31,19 @@ async def handle_monitoring(
     _logger.info("Press Ctrl+C to stop.")
 
     def on_status_update(status: DeviceStatus) -> None:
+        unit_suffix = "°C" if get_unit_system() == "metric" else "°F"
         _logger.info(
-            f"Received status update: Temp={status.dhwTemperature}°F, "
-            f"Power={'ON' if status.dhwUse else 'OFF'}"
+            f"Received status update: Temp={status.dhw_temperature}"
+            f"{unit_suffix}, "
+            f"Power={'ON' if status.dhw_use else 'OFF'}"
         )
         write_status_to_csv(output_file, status)
 
     await mqtt.subscribe_device_status(device, on_status_update)
-    await mqtt.start_periodic_device_status_requests(device, period_seconds=30)
-    await mqtt.request_device_status(device)  # Get an initial status right away
+    await mqtt.start_periodic_requests(device, period_seconds=30)
+    await mqtt.control.request_device_status(
+        device
+    )  # Get an initial status right away
 
     # Keep the script running indefinitely
     await asyncio.Event().wait()
